module.exports = defineTest({
	description: 'deoptimizes var variables in hoisted scopes'
});
